@@ -19,10 +19,46 @@ if 'phonostats' in settings.INSTALLED_APPS:
 if 'celex' in settings.INSTALLED_APPS:
     from celex.utils import lookupFreq,lookupCat
 
-from .utils import fetch_buckeye_resource
+from .helper import fetch_buckeye_resource,reorganize
 from .managers import BulkManager
 
-p = PraatLoader(settings.PRAAT_PATH,debug=settings.DEBUG)
+
+GOOD_WORDS = ['back', 'bad', 'badge', 'bag', 'ball', 'bar', 'bare', 'base', 'bash', 'bass', 'bat', 'bath', 'beach', 'bean', 'bear', 'beat',
+                 'bed', 'beer', 'bell', 'berth', 'big', 'bike', 'bill', 'birth', 'bitch', 'bite', 'boat', 'bob', 'boil', 'bomb', 'book', 'boom', 'boon',
+                 'boss', 'bought', 'bout', 'bowl', 'buck', 'bum', 'burn', 'bus', 'bush', 'cab', 'cad', 'cake', 'calf', 'call', 'came', 'cap',
+                 'car', 'care', 'case', 'cash', 'cat', 'catch', 'caught', 'cave', 'cell', 'chain', 'chair', 'chat', 'cheap', 'cheat', 'check',
+                 'cheer', 'cheese', 'chess', 'chick', 'chief', 'chill', 'choice', 'choose', 'chose', 'church', 'coach', 'code', 'coke',
+                 'comb', 'come', 'cone', 'cook', 'cool', 'cop', 'cope', 'corps', 'couch', 'cough', 'cub', 'cuff', 'cup', 'curl', 'curve', 'cut',
+                 'dab', 'dad', 'dare', 'date', 'dawn', 'dead', 'deal', 'dear', 'death', 'debt', 'deck', 'deed', 'deep', 'deer', 'dime', 'dirt',
+                 'doc', 'dodge', 'dog', 'dole', 'doll', 'doom', 'door', 'dot', 'doubt', 'duck', 'dug', 'dumb', 'face', 'fad', 'fade', 'fail',
+                 'fair', 'faith', 'fake', 'fall', 'fame', 'fan', 'far', 'fat', 'faze', 'fear', 'fed', 'feed', 'feet', 'fell', 'fight', 'file', 'fill', 'fine',
+                 'firm', 'fish', 'fit', 'fog', 'folk', 'food', 'fool', 'foot', 'fore', 'fought', 'fun', 'fuss', 'gain', 'game', 'gap', 'gas',
+                 'gate', 'gave', 'gear', 'geese', 'gig', 'girl', 'give', 'goal', 'gone', 'good', 'goose', 'gum', 'gun', 'gut', 'gym', 'hail', 'hair',
+                 'hall', 'ham', 'hang', 'hash', 'hat', 'hate', 'head', 'hear', 'heard', 'heat', 'height', 'hick', 'hid', 'hide', 'hill', 'hip', 'hit',
+                 'hole', 'home', 'hood', 'hook', 'hop', 'hope', 'hot', 'house', 'hug', 'hum', 'hung', 'hurt', 'jab', 'jail', 'jam', 'jazz', 'jerk',
+                 'jet', 'job', 'jog', 'join', 'joke', 'judge', 'june', 'keep', 'kick', 'kid', 'kill', 'king', 'kiss', 'knife', 'knit', 'knob', 'knock',
+                 'known', 'lack', 'lag', 'laid', 'lake', 'lame', 'lane', 'lash', 'latch', 'late', 'laugh', 'lawn', 'league', 'leak', 'lean', 'learn',
+                 'lease', 'leash', 'leave', 'led', 'leg', 'let', 'lid', 'life', 'light', 'line', 'load', 'loan', 'lock', 'lodge', 'lone', 'long', 'look',
+                 'loose', 'lose', 'loss', 'loud', 'love', 'loyal', 'luck', 'mad', 'made', 'maid', 'mail', 'main', 'make', 'male', 'mall',
+                 'map', 'mass', 'mat', 'match', 'math', 'meal', 'meat', 'meet', 'men', 'mess', 'met', 'mid', 'mike', 'mile', 'mill',
+                 'miss', 'mock', 'moon', 'mouth', 'move', 'mud', 'nail', 'name', 'nap', 'neat', 'neck', 'need', 'nerve', 'net', 'news',
+                 'nice', 'niche', 'niece', 'night', 'noise', 'noon', 'nose', 'notch', 'note', 'noun', 'nurse', 'nut', 'pace', 'pack', 'page',
+                 'paid', 'pain', 'pair', 'pal', 'pass', 'pat', 'path', 'pawn', 'peace', 'peak', 'pearl', 'peek', 'peer', 'pen', 'pet', 'phase',
+                 'phone', 'pick', 'piece', 'pile', 'pill', 'pine', 'pipe', 'pit', 'pool', 'poor', 'pop', 'pope', 'pot', 'pour', 'puck', 'push',
+                 'put', 'race', 'rage', 'rail', 'rain', 'raise', 'ran', 'rash', 'rat', 'rate', 'rave', 'reach', 'rear', 'red', 'reef', 'reel',
+                 'rice', 'rich', 'ride', 'ring', 'rise', 'road', 'roam', 'rob', 'rock', 'rode', 'role', 'roll', 'roof', 'room', 'rose', 'rough',
+                 'rub', 'rude', 'rule', 'run', 'rush', 'sack', 'sad', 'safe', 'said', 'sake', 'sale', 'sang', 'sat', 'save', 'scene', 'search',
+                 'seat', 'seen', 'sell', 'serve', 'set', 'sewn', 'shake', 'shame', 'shape', 'share', 'shave', 'shed', 'sheep', 'sheer', 'sheet',
+                 'shell', 'ship', 'shirt', 'shock', 'shoot', 'shop', 'shot', 'shown', 'shun', 'shut', 'sick', 'side', 'sight', 'sign', 'sin', 'sing',
+                 'sit', 'site', 'size', 'soap', 'son', 'song', 'soon', 'soul', 'soup', 'south', 'suit', 'sung', 'tab', 'tag', 'tail', 'take', 'talk',
+                 'tap', 'tape', 'taught', 'teach', 'team', 'tease', 'teeth', 'tell', 'term', 'theme', 'thick', 'thief', 'thing', 'thought', 'tiff',
+                 'tight', 'time', 'tip', 'tongue', 'took', 'tool', 'top', 'tore', 'toss', 'touch', 'tough', 'tour', 'towel', 'town', 'tub', 'tube',
+                 'tune', 'turn', 'type', 'use', 'van', 'vet', 'vice', 'voice', 'vote', 'wade', 'wage', 'wait', 'wake', 'walk', 'wall', 'war',
+                 'wash', 'watch', 'wear', 'web', 'week', 'weight', 'wet', 'whack', 'wheat', 'wheel', 'whim', 'whine', 'whip', 'white',
+                 'whole', 'wick', 'wide', 'wife', 'win', 'wine', 'wing', 'wise', 'wish', 'woke', 'womb', 'wood', 'word', 'wore', 'work',
+                 'worse', 'wreck', 'wright', 'write', 'wrong', 'wrote', 'wrought', 'year', 'yell', 'young', 'youth', 'zip']
+    #Remove: pull, full, bull, real
+VOWELS = ['aa','ae','eh','ey','ih','iy','ow','uh','uw']
 
 class WTManager(BulkManager):
     tbl_name = "buckeyebrowser_wordtoken"
@@ -98,6 +134,18 @@ Group by StressVowel) AS averages""",[self.pk])
         dialogs = sorted(set([ f[3:5] for f in files]))
         Dialog.objects.bulk_create([ Dialog(Speaker=self,Number=d) for d in dialogs])
 
+    def analyze(self,form):
+        words = WordToken.objects.filter(Dialog__Speaker=self)
+        words = words.filter(WordType__CVSkel='CVC')
+        #words = words.filter(WordType__StressVowel__in = VOWELS)
+        words = words.filter(WordType__Label__in = GOOD_WORDS).order_by('Dialog')
+        allout = []
+        for w in words:
+            if not w.isAcceptable():
+                continue
+            allout.extend(w.getAnalysisLines(form))
+        return allout
+
     def load_dialogs(self):
         self.create_dialogs()
         for d in Dialog.objects.filter(Speaker = self):
@@ -123,7 +171,46 @@ class Dialog(models.Model):
 
     def load_in(self):
         wf = self.get_word_files()
-        #for f in wf:
+        for f in wf:
+            name = re.sub(".words","",f)
+            words = reorganize(self.Speaker.get_path(),name)
+            cat = Category.objects.get(Label=word['Category'])
+            wordTypes = WordType.objects.filter(Label=word['Word'])
+            ur = word['UR'].split(";")
+            w = None
+            if w is None and len(wordTypes) != 0:
+                for wType in wordTypes:
+                    if wType.isWord() and wType.getUR() == word['UR']:
+                        w = wType
+                        break
+                    elif not wType.isWord():
+                        w = wType
+            if w is None:
+                w = WordType.objects.create(Label=word['Word'],Count=0)
+                if w.isWord():
+                    uls = []
+                    cv = ''
+                    for i in range(len(ur)):
+                        sType = SegmentType.objects.get(Label=ur[i])
+                        if sType.isVowel():
+                            cv += 'V'
+                        else:
+                            cv += 'C'
+                        uls.append(Underlying(WordType=w,SegmentType=sType,Ordering=i))
+                    if cv == 'CVC':
+                        w.StressVowel = ur[1]
+                        uls[-2].Stressed = 1
+                    w.CVSkel = cv
+                    w.save()
+                    Underlying.objects.bulk_create(uls)
+            wt =WordToken.objects.create(Begin=word['Begin'],End=word['End'],WordType=w,Category=cat,Dialog=self,DialogPart=name[-1])
+            if w.isWord():
+                sts = []
+                for s in word['phonerange']:
+                    sType = SegmentType.objects.get(Label=s['Label'])
+                    sts.append(SegmentToken(WordToken=wt,SegmentType = sType,Begin=s['Begin'],End=s['End']))
+                SegmentToken.objects.bulk_create(sts)
+
 
 
 class SegmentType(models.Model):
@@ -530,6 +617,7 @@ class WordToken(models.Model):
             self.StrVowelF2 = formants[1]
             self.save()
         else:
+            p = PraatLoader(settings.PRAAT_PATH,debug=settings.DEBUG)
             path = str(self.Dialog.Speaker) + "/" + str(self.Dialog)+self.DialogPart
             begin,end = self.getStressedVowelInfo()
             ceiling = self.getCeiling()
@@ -795,6 +883,7 @@ class WordToken(models.Model):
         return fc.getProb()
 
     def createPictures(self):
+        p = PraatLoader(settings.PRAAT_PATH,debug=settings.DEBUG)
         wavpath = os.path.join(settings.TEMP_DIR,"Buckeye-"+str(self.pk)+".wav")
         outpath = os.path.join(settings.TEMP_DIR,"Buckeye-"+str(self.pk)+".mp3")
         specepspath = os.path.join(settings.TEMP_DIR,"Buckeye-"+str(self.pk)+"-spectro.eps")
